diff --git a/compiled/facebook-www/REVISION b/compiled/facebook-www/REVISION
index 4edf1b4903..03a2c73226 100644
--- a/compiled/facebook-www/REVISION
+++ b/compiled/facebook-www/REVISION
@@ -1 +1 @@
-b4cdd3e8922713f8c9817b004a0dc51be47bc5df
+9d4582dffdea5b4dcb6a6093ea848d15423c7701
diff --git a/compiled/facebook-www/ReactDOMServer-dev.classic.js b/compiled/facebook-www/ReactDOMServer-dev.classic.js
index 36aeb132a9..4f269a415d 100644
--- a/compiled/facebook-www/ReactDOMServer-dev.classic.js
+++ b/compiled/facebook-www/ReactDOMServer-dev.classic.js
@@ -19,7 +19,7 @@ if (__DEV__) {
var React = require("react");
var ReactDOM = require("react-dom");
-var ReactVersion = "18.3.0-www-classic-1747ba9c";
+var ReactVersion = "18.3.0-www-classic-dbbf9e79";
// This refers to a WWW module.
var warningWWW = require("warning");
@@ -1910,7 +1910,7 @@ var scriptIntegirty = stringToPrecomputedChunk('" integrity="');
var scriptCrossOrigin = stringToPrecomputedChunk('" crossorigin="');
var endAsyncScript = stringToPrecomputedChunk('" async="">');
/**
* This escaping function is designed to work with bootstrapScriptContent only.
* because we know we are escaping the entire script. We can avoid for instance
* escaping html comment string sequences that are valid javascript as well because
* if there are no sebsequent ');
* ensure that the script cannot be early terminated or never terminated state
*/
-function escapeBootstrapScriptContent(scriptText) {
+function escapeBootstrapAndImportMapScriptContent(scriptText) {
{
checkHtmlStringCoercion(scriptText);
}
@@ -1932,11 +1932,16 @@ var scriptRegex = /(<\/|<)(s)(cript)/gi;
var scriptReplacer = function (match, prefix, s, suffix) {
return "" + prefix + (s === "s" ? "\\u0073" : "\\u0053") + suffix;
-}; // Allows us to keep track of what we've already written so we can refer back to it.
+};
+
+var importMapScriptStart = stringToPrecomputedChunk(
+ '"); // Allows us to keep track of what we've already written so we can refer back to it.
// if passed externalRuntimeConfig and the enableFizzExternalRuntime feature flag
// is set, the server will send instructions via data attributes (instead of inline scripts)
-function createRenderState$1(resumableState, nonce) {
+function createRenderState$1(resumableState, nonce, importMap) {
var inlineScriptWithNonce =
nonce === undefined
? startInlineScript
@@ -1944,6 +1949,19 @@ function createRenderState$1(resumableState, nonce) {
'');
/**
* This escaping function is designed to work with bootstrapScriptContent only.
* because we know we are escaping the entire script. We can avoid for instance
* escaping html comment string sequences that are valid javascript as well because
* if there are no sebsequent ');
* ensure that the script cannot be early terminated or never terminated state
*/
-function escapeBootstrapScriptContent(scriptText) {
+function escapeBootstrapAndImportMapScriptContent(scriptText) {
{
checkHtmlStringCoercion(scriptText);
}
@@ -1932,11 +1932,16 @@ var scriptRegex = /(<\/|<)(s)(cript)/gi;
var scriptReplacer = function (match, prefix, s, suffix) {
return "" + prefix + (s === "s" ? "\\u0073" : "\\u0053") + suffix;
-}; // Allows us to keep track of what we've already written so we can refer back to it.
+};
+
+var importMapScriptStart = stringToPrecomputedChunk(
+ '"); // Allows us to keep track of what we've already written so we can refer back to it.
// if passed externalRuntimeConfig and the enableFizzExternalRuntime feature flag
// is set, the server will send instructions via data attributes (instead of inline scripts)
-function createRenderState$1(resumableState, nonce) {
+function createRenderState$1(resumableState, nonce, importMap) {
var inlineScriptWithNonce =
nonce === undefined
? startInlineScript
@@ -1944,6 +1949,19 @@ function createRenderState$1(resumableState, nonce) {
'');
/**
* This escaping function is designed to work with bootstrapScriptContent only.
* because we know we are escaping the entire script. We can avoid for instance
* escaping html comment string sequences that are valid javascript as well because
* if there are no sebsequent ');
* ensure that the script cannot be early terminated or never terminated state
*/
-function escapeBootstrapScriptContent(scriptText) {
+function escapeBootstrapAndImportMapScriptContent(scriptText) {
{
checkHtmlStringCoercion(scriptText);
}
@@ -1929,11 +1929,16 @@ var scriptRegex = /(<\/|<)(s)(cript)/gi;
var scriptReplacer = function (match, prefix, s, suffix) {
return "" + prefix + (s === "s" ? "\\u0073" : "\\u0053") + suffix;
-}; // Allows us to keep track of what we've already written so we can refer back to it.
+};
+
+var importMapScriptStart = stringToPrecomputedChunk(
+ '"); // Allows us to keep track of what we've already written so we can refer back to it.
// if passed externalRuntimeConfig and the enableFizzExternalRuntime feature flag
// is set, the server will send instructions via data attributes (instead of inline scripts)
-function createRenderState(resumableState, nonce) {
+function createRenderState(resumableState, nonce, importMap) {
var inlineScriptWithNonce =
nonce === undefined
? startInlineScript
@@ -1941,6 +1946,19 @@ function createRenderState(resumableState, nonce) {
'
@@ -1910,7 +1910,7 @@ var scriptIntegirty = stringToPrecomputedChunk('" integrity="');
var endAsyncScript = stringToPrecomputedChunk('" async="">');
/**
- * This escaping function is designed to work with bootstrapScriptContent only.
+ * This escaping function is designed to work with bootstrapScriptContent and importMap only.
* because we know we are escaping the entire script. We can avoid for instance
* escaping html comment string sequences that are valid javascript as well because
@@ -1944,6 +1949,19 @@ function createRenderState$1(resumableState, nonce) {
'');
/**
- * This escaping function is designed to work with bootstrapScriptContent only.
+ * This escaping function is designed to work with bootstrapScriptContent and importMap only.
* because we know we are escaping the entire script. We can avoid for instance
* escaping html comment string sequences that are valid javascript as well because
@@ -1944,6 +1949,19 @@ function createRenderState$1(resumableState, nonce) {
'');
/**
- * This escaping function is designed to work with bootstrapScriptContent only.
+ * This escaping function is designed to work with bootstrapScriptContent and importMap only.
* because we know we are escaping the entire script. We can avoid for instance
* escaping html comment string sequences that are valid javascript as well because